﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;

using MindFusion.Diagramming;
using MindFusion.Diagramming.Lanes;

using Orientation = MindFusion.Diagramming.Orientation;
using SolidBrush = MindFusion.Drawing.SolidBrush;
using Pen = MindFusion.Drawing.Pen;


namespace Lanes
{
	public partial class _Default : System.Web.UI.Page
	{
		protected void Page_Load(object sender, EventArgs e)
		{
			if (!IsPostBack)
			{
				Diagram diagram = diagramView.Diagram;

				// set up the diagram defaults
                diagram.LinkShape = LinkShape.Cascading;
				diagram.LinkSegments = 2;
				diagram.LinkCascadeOrientation =Orientation.Horizontal;
				diagram.SnapToAnchor = SnapToAnchor.OnCreateOrModify;
				diagram.LinkHeadShape = Shapes.Alternative;
				diagram.LinkHeadShapeSize = 1.4f;
				diagram.ShadowOffsetX = 0.6f;
				diagram.ShadowOffsetY = 0.6f;
				diagram.DefaultShape = Shapes.Rectangle;
				diagram.AllowSelfLoops = false;
				diagram.AlignToGrid = false;

                DiagramStyle style = new DiagramStyle();
                style.ShadowBrush = new SolidBrush(Color.FromArgb(40, Color.Black));
                diagram.Style = style;

				// initialize swimlane grid
				diagram.EnableLanes = true;
				Grid grid = diagram.LaneGrid;
				HeaderCollection columns = grid.ColumnHeaders;

				grid.MinHeaderSize = 8;
				grid.HookHeaders = false;
				grid.HeadersOnTop = false;
				grid.ColumnHeadersHeights = new float[] { 8, 8 };
				grid.AlignCells = false;
				grid.AllowResizeHeaders = true;

				// create columns for weeks and child columns for days
				for (int i = 1; i <= 8; i++)
				{
					Header header = new Header("Week " + i + ", 2011");
					header.SubHeaders.Add(new Header("S"));
					header.SubHeaders.Add(new Header("M"));
					header.SubHeaders.Add(new Header("T"));
					header.SubHeaders.Add(new Header("W"));
					header.SubHeaders.Add(new Header("T"));
					header.SubHeaders.Add(new Header("F"));
					header.SubHeaders.Add(new Header("S"));
					columns.Add(header);
				}

				// create rows for tasks
				for (int i = 1; i <= 6; i++)
					grid.RowHeaders.Add(new Header("Task " + i));

				var dottedPen = new Pen(Color.FromArgb(0xE2, 0xE5, 0xE8), 1);
				var darkPen = new Pen(Color.FromArgb(0x72, 0x74, 0x77), 1);
				var transparentPen = new Pen(Color.Transparent, 1);

				// customize cell appearance
				int columnCount = 8 * 7;
				for (int i = 0; i < columnCount; i++)
				{
					Header column = grid.GetColumn(i);

					grid[column, null].Style.LeftBorderPen = i % 7 != 0 ? dottedPen : darkPen;
					if (i != columnCount - 1)
						grid[column, null].Style.RightBorderPen = transparentPen;

					if (i % 7 == 0 || i % 7 == 6)
						grid[column, null].Style.BackgroundBrush = new SolidBrush(Color.PaleGoldenrod);
				}

				int rowCount = 6;
				for (int i = 0; i < rowCount; i++)
				{
					Header row = grid.GetRow(i);

					if (i != 0)
						grid[null, row].Style.TopBorderPen = darkPen;
					if (i != rowCount - 1)
						grid[null, row].Style.BottomBorderPen = transparentPen;
				}

				// Ensure the document is big enough to contain the grid
				var bounds = RectangleF.Union(grid.GetRowHeaderBounds(), grid.GetColumnHeaderBounds());
				bounds.Width += 10;
				bounds.Height += 10;
				diagram.Bounds = bounds;
			}
		}
	}
}